"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, execution_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes an execution.  This operation is eventually consistent. The results are best effort and may not reflect very recent updates and changes.  This API action is not supported by EXPRESS state machines.

    Args:
        execution_arn(str): The Amazon Resource Name (ARN) of the execution to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.stepfunction.execution.init.describe(ctx, execution_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.stepfunction.execution.init.describe execution_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="stepfunctions",
        operation="describe_execution",
        op_kwargs={"executionArn": execution_arn},
    )


async def list_all(
    hub,
    ctx,
    state_machine_arn: str,
    status_filter: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the executions of a state machine that meet the filtering criteria. Results are sorted by time, with the most recent execution first. If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 24 hours. Using an expired pagination token will return an HTTP 400 InvalidToken error.  This operation is eventually consistent. The results are best effort and may not reflect very recent updates and changes.  This API action is not supported by EXPRESS state machines.

    Args:
        state_machine_arn(str): The Amazon Resource Name (ARN) of the state machine whose executions is listed.
        status_filter(str, optional): If specified, only list the executions whose current execution status matches the given filter. Defaults to None.
        max_results(int, optional): The maximum number of results that are returned per call. You can use nextToken to obtain further pages of results. The default is 100 and the maximum allowed page size is 1000. A value of 0 uses the default. This is only an upper limit. The actual number of results returned per call might be fewer than the specified maximum. Defaults to None.
        next_token(str, optional): If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 24 hours. Using an expired pagination token will return an HTTP 400 InvalidToken error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.stepfunction.execution.init.list_all(
                ctx, state_machine_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.stepfunction.execution.init.list_all state_machine_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="stepfunctions",
        operation="list_executions",
        op_kwargs={
            "stateMachineArn": state_machine_arn,
            "statusFilter": status_filter,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )


async def start(
    hub,
    ctx,
    state_machine_arn: str,
    name: str = None,
    input_: str = None,
    trace_header: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts a state machine execution.   StartExecution is idempotent. If StartExecution is called with the same name and input as a running execution, the call will succeed and return the same response as the original request. If the execution is closed or if the input is different, it will return a 400 ExecutionAlreadyExists error. Names can be reused after 90 days.

    Args:
        state_machine_arn(str): The Amazon Resource Name (ARN) of the state machine to execute.
        name(str, optional): The name of the execution. This name must be unique for your AWS account, region, and state machine for 90 days. For more information, see  Limits Related to State Machine Executions in the AWS Step Functions Developer Guide. A name must not contain:   white space   brackets < > { } [ ]    wildcard characters ? *    special characters " # % \ ^ | ~ ` $ & , ; : /    control characters (U+0000-001F, U+007F-009F)   To enable logging with CloudWatch Logs, the name should only contain 0-9, A-Z, a-z, - and _. Defaults to None.
        input_(str, optional): The string that contains the JSON input data for the execution, for example:  "input": "{\"first_name\" : \"test\"}"   If you don't include any JSON input data, you still must include the two braces, for example: "input": "{}"   Length constraints apply to the payload size, and are expressed as bytes in UTF-8 encoding. Defaults to None.
        trace_header(str, optional): Passes the AWS X-Ray trace header. The trace header can also be passed in the request payload. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.stepfunction.execution.init.start(ctx, state_machine_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.stepfunction.execution.init.start state_machine_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="stepfunctions",
        operation="start_execution",
        op_kwargs={
            "stateMachineArn": state_machine_arn,
            "name": name,
            "input": input_,
            "traceHeader": trace_header,
        },
    )


async def stop(
    hub, ctx, execution_arn: str, error: str = None, cause: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Stops an execution. This API action is not supported by EXPRESS state machines.

    Args:
        execution_arn(str): The Amazon Resource Name (ARN) of the execution to stop.
        error(str, optional): The error code of the failure. Defaults to None.
        cause(str, optional): A more detailed explanation of the cause of the failure. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.stepfunction.execution.init.stop(ctx, execution_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.stepfunction.execution.init.stop execution_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="stepfunctions",
        operation="stop_execution",
        op_kwargs={"executionArn": execution_arn, "error": error, "cause": cause},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(hub, ctx, fleet_name: str, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the name of the stack with which the specified fleet is associated.

    Args:
        fleet_name(str): The name of the fleet.
        next_token(str, optional): The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.associated.stack.list_all(ctx, fleet_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.associated.stack.list_all fleet_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="list_associated_stacks",
        op_kwargs={"FleetName": fleet_name, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, file_system_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the FileSystemPolicy for the specified file system. The default FileSystemPolicy goes into effect once the existing policy is deleted. For more information about the default file system policy, see Using Resource-based Policies with EFS. This operation requires permissions for the elasticfilesystem:DeleteFileSystemPolicy action.

    Args:
        file_system_id(str): Specifies the EFS file system for which to delete the FileSystemPolicy.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.efs.file_system.policy.delete(ctx, file_system_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.efs.file_system.policy.delete file_system_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="efs",
        operation="delete_file_system_policy",
        op_kwargs={"FileSystemId": file_system_id},
    )


async def describe(hub, ctx, file_system_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the FileSystemPolicy for the specified EFS file system. This operation requires permissions for the elasticfilesystem:DescribeFileSystemPolicy action.

    Args:
        file_system_id(str): Specifies which EFS file system to retrieve the FileSystemPolicy for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.efs.file_system.policy.describe(ctx, file_system_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.efs.file_system.policy.describe file_system_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="efs",
        operation="describe_file_system_policy",
        op_kwargs={"FileSystemId": file_system_id},
    )


async def put(
    hub,
    ctx,
    file_system_id: str,
    policy: str,
    bypass_policy_lockout_safety_check: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Applies an Amazon EFS FileSystemPolicy to an Amazon EFS file system. A file system policy is an IAM resource-based policy and can contain multiple policy statements. A file system always has exactly one file system policy, which can be the default policy or an explicit policy set or updated using this API operation. EFS file system policies have a 20,000 character limit. When an explicit policy is set, it overrides the default policy. For more information about the default file system policy, see Default EFS File System Policy.  EFS file system policies have a 20,000 character limit. This operation requires permissions for the elasticfilesystem:PutFileSystemPolicy action.

    Args:
        file_system_id(str): The ID of the EFS file system that you want to create or update the FileSystemPolicy for.
        policy(str): The FileSystemPolicy that you're creating. Accepts a JSON formatted policy definition. EFS file system policies have a 20,000 character limit. To find out more about the elements that make up a file system policy, see EFS Resource-based Policies. .
        bypass_policy_lockout_safety_check(bool, optional): (Optional) A flag to indicate whether to bypass the FileSystemPolicy lockout safety check. The policy lockout safety check determines whether the policy in the request will prevent the principal making the request will be locked out from making future PutFileSystemPolicy requests on the file system. Set BypassPolicyLockoutSafetyCheck to True only when you intend to prevent the principal that is making the request from making a subsequent PutFileSystemPolicy request on the file system. The default value is False. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.efs.file_system.policy.put(
                ctx, file_system_id=value, policy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.efs.file_system.policy.put file_system_id=value, policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="efs",
        operation="put_file_system_policy",
        op_kwargs={
            "FileSystemId": file_system_id,
            "Policy": policy,
            "BypassPolicyLockoutSafetyCheck": bypass_policy_lockout_safety_check,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, cache_policy_config: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Creates a cache policy. After you create a cache policy, you can attach it to one or more cache behaviors. When it’s attached to a cache behavior, the cache policy determines the following:   The values that CloudFront includes in the cache key. These values can include HTTP headers, cookies, and URL query strings. CloudFront uses the cache key to find an object in its cache that it can return to the viewer.   The default, minimum, and maximum time to live (TTL) values that you want objects to stay in the CloudFront cache.   The headers, cookies, and query strings that are included in the cache key are automatically included in requests that CloudFront sends to the origin. CloudFront sends a request when it can’t find an object in its cache that matches the request’s cache key. If you want to send values to the origin but not include them in the cache key, use OriginRequestPolicy. For more information about cache policies, see Controlling the cache key in the Amazon CloudFront Developer Guide.

    Args:
        cache_policy_config(Dict): A cache policy configuration.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.cache_policy.init.create(
                ctx, cache_policy_config=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.cache_policy.init.create cache_policy_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="create_cache_policy",
        op_kwargs={"CachePolicyConfig": cache_policy_config},
    )


async def delete(hub, ctx, id_: str, if_match: str = None) -> None:
    r"""
    **Autogenerated function**

    Deletes a cache policy. You cannot delete a cache policy if it’s attached to a cache behavior. First update your distributions to remove the cache policy from all cache behaviors, then delete the cache policy. To delete a cache policy, you must provide the policy’s identifier and version. To get these values, you can use ListCachePolicies or GetCachePolicy.

    Args:
        id_(str): The unique identifier for the cache policy that you are deleting. To get the identifier, you can use ListCachePolicies.
        if_match(str, optional): The version of the cache policy that you are deleting. The version is the cache policy’s ETag value, which you can get using ListCachePolicies, GetCachePolicy, or GetCachePolicyConfig. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.cache_policy.init.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.cache_policy.init.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="delete_cache_policy",
        op_kwargs={"Id": id_, "IfMatch": if_match},
    )


async def get(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets a cache policy, including the following metadata:   The policy’s identifier.   The date and time when the policy was last modified.   To get a cache policy, you must provide the policy’s identifier. If the cache policy is attached to a distribution’s cache behavior, you can get the policy’s identifier using ListDistributions or GetDistribution. If the cache policy is not attached to a cache behavior, you can get the identifier using ListCachePolicies.

    Args:
        id_(str): The unique identifier for the cache policy. If the cache policy is attached to a distribution’s cache behavior, you can get the policy’s identifier using ListDistributions or GetDistribution. If the cache policy is not attached to a cache behavior, you can get the identifier using ListCachePolicies.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.cache_policy.init.get(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.cache_policy.init.get id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="get_cache_policy",
        op_kwargs={"Id": id_},
    )


async def list_all(
    hub, ctx, type_: str = None, marker: str = None, max_items: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of cache policies. You can optionally apply a filter to return only the managed policies created by Amazon Web Services, or only the custom policies created in your account. You can optionally specify the maximum number of items to receive in the response. If the total number of items in the list exceeds the maximum that you specify, or the default maximum, the response is paginated. To get the next page of items, send a subsequent request that specifies the NextMarker value from the current response as the Marker value in the subsequent request.

    Args:
        type_(str, optional): A filter to return only the specified kinds of cache policies. Valid values are:    managed – Returns only the managed policies created by Amazon Web Services.    custom – Returns only the custom policies created in your account.  . Defaults to None.
        marker(str, optional): Use this field when paginating results to indicate where to begin in your list of cache policies. The response includes cache policies in the list that occur after the marker. To get the next page of the list, set this field’s value to the value of NextMarker from the current page’s response. Defaults to None.
        max_items(str, optional): The maximum number of cache policies that you want in the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.cache_policy.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.cache_policy.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="list_cache_policies",
        op_kwargs={"Type": type_, "Marker": marker, "MaxItems": max_items},
    )


async def update(
    hub, ctx, cache_policy_config: Dict, id_: str, if_match: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a cache policy configuration. When you update a cache policy configuration, all the fields are updated with the values provided in the request. You cannot update some fields independent of others. To update a cache policy configuration:   Use GetCachePolicyConfig to get the current configuration.   Locally modify the fields in the cache policy configuration that you want to update.   Call UpdateCachePolicy by providing the entire cache policy configuration, including the fields that you modified and those that you didn’t.

    Args:
        cache_policy_config(Dict): A cache policy configuration.
        id_(str): The unique identifier for the cache policy that you are updating. The identifier is returned in a cache behavior’s CachePolicyId field in the response to GetDistributionConfig.
        if_match(str, optional): The version of the cache policy that you are updating. The version is returned in the cache policy’s ETag field in the response to GetCachePolicyConfig. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.cache_policy.init.update(
                ctx, cache_policy_config=value, id_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.cache_policy.init.update cache_policy_config=value, id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="update_cache_policy",
        op_kwargs={
            "CachePolicyConfig": cache_policy_config,
            "Id": id_,
            "IfMatch": if_match,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(hub, ctx, thing_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the connectivity information for a core.

    Args:
        thing_name(str): The thing name.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.connectivity_info.get(ctx, thing_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.connectivity_info.get thing_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="get_connectivity_info",
        op_kwargs={"ThingName": thing_name},
    )


async def update(hub, ctx, thing_name: str, connectivity_info: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates the connectivity information for the core. Any devices that belong to the group which has this core will receive this information in order to find the location of the core and connect to it.

    Args:
        connectivity_info(List, optional): A list of connectivity info. Defaults to None.
        thing_name(str): The thing name.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.connectivity_info.update(ctx, thing_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.connectivity_info.update thing_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="update_connectivity_info",
        op_kwargs={"ConnectivityInfo": connectivity_info, "ThingName": thing_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    dry_run: bool = None,
    location_type: str = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of all instance types offered. The results can be filtered by location (Region or Availability Zone). If no location is specified, the instance types offered in the current Region are returned.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        location_type(str, optional): The location type. Defaults to None.
        filters(List, optional): One or more filters. Filter names and values are case-sensitive.    location - This depends on the location type. For example, if the location type is region (default), the location is the Region code (for example, us-east-2.)    instance-type - The instance type. For example, c5.2xlarge.  . Defaults to None.
        max_results(int, optional): The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the next token value. Defaults to None.
        next_token(str, optional): The token to retrieve the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.instance.type_.offering.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.instance.type_.offering.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_instance_type_offerings",
        op_kwargs={
            "DryRun": dry_run,
            "LocationType": location_type,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    model_package_name: str = None,
    model_package_group_name: str = None,
    model_package_description: str = None,
    inference_specification: Dict = None,
    validation_specification: Dict = None,
    source_algorithm_specification: Dict = None,
    certify_for_marketplace: bool = None,
    tags: List = None,
    model_approval_status: str = None,
    metadata_properties: Dict = None,
    model_metrics: Dict = None,
    client_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a model package that you can use to create Amazon SageMaker models or list on Amazon Web Services Marketplace, or a versioned model that is part of a model group. Buyers can subscribe to model packages listed on Amazon Web Services Marketplace to create models in Amazon SageMaker. To create a model package by specifying a Docker container that contains your inference code and the Amazon S3 location of your model artifacts, provide values for InferenceSpecification. To create a model from an algorithm resource that you created or subscribed to in Amazon Web Services Marketplace, provide a value for SourceAlgorithmSpecification.  There are two types of model packages:   Versioned - a model that is part of a model group in the model registry.   Unversioned - a model package that is not part of a model group.

    Args:
        model_package_name(str, optional): The name of the model package. The name must have 1 to 63 characters. Valid characters are a-z, A-Z, 0-9, and - (hyphen). This parameter is required for unversioned models. It is not applicable to versioned models. Defaults to None.
        model_package_group_name(str, optional): The name of the model group that this model version belongs to. This parameter is required for versioned models, and does not apply to unversioned models. Defaults to None.
        model_package_description(str, optional): A description of the model package. Defaults to None.
        inference_specification(Dict, optional): Specifies details about inference jobs that can be run with models based on this model package, including the following:   The Amazon ECR paths of containers that contain the inference code and model artifacts.   The instance types that the model package supports for transform jobs and real-time endpoints used for inference.   The input and output content formats that the model package supports for inference.  . Defaults to None.
        validation_specification(Dict, optional): Specifies configurations for one or more transform jobs that Amazon SageMaker runs to test the model package. Defaults to None.
        source_algorithm_specification(Dict, optional): Details about the algorithm that was used to create the model package. Defaults to None.
        certify_for_marketplace(bool, optional): Whether to certify the model package for listing on Amazon Web Services Marketplace. This parameter is optional for unversioned models, and does not apply to versioned models. Defaults to None.
        tags(List, optional): A list of key value pairs associated with the model. For more information, see Tagging Amazon Web Services resources in the Amazon Web Services General Reference Guide. Defaults to None.
        model_approval_status(str, optional): Whether the model is approved for deployment. This parameter is optional for versioned models, and does not apply to unversioned models. For versioned models, the value of this parameter must be set to Approved to deploy the model. Defaults to None.
        metadata_properties(Dict, optional): Metadata properties of the tracking entity, trial, or trial component. Defaults to None.
        model_metrics(Dict, optional): A structure that contains model metrics reports. Defaults to None.
        client_token(str, optional): A unique token that guarantees that the call to this API is idempotent. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.model.package.init.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.model.package.init.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_model_package",
        op_kwargs={
            "ModelPackageName": model_package_name,
            "ModelPackageGroupName": model_package_group_name,
            "ModelPackageDescription": model_package_description,
            "InferenceSpecification": inference_specification,
            "ValidationSpecification": validation_specification,
            "SourceAlgorithmSpecification": source_algorithm_specification,
            "CertifyForMarketplace": certify_for_marketplace,
            "Tags": tags,
            "ModelApprovalStatus": model_approval_status,
            "MetadataProperties": metadata_properties,
            "ModelMetrics": model_metrics,
            "ClientToken": client_token,
        },
    )


async def delete(hub, ctx, model_package_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a model package. A model package is used to create Amazon SageMaker models or list on Amazon Web Services Marketplace. Buyers can subscribe to model packages listed on Amazon Web Services Marketplace to create models in Amazon SageMaker.

    Args:
        model_package_name(str): The name or Amazon Resource Name (ARN) of the model package to delete. When you specify a name, the name must have 1 to 63 characters. Valid characters are a-z, A-Z, 0-9, and - (hyphen).
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.model.package.init.delete(
                ctx, model_package_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.model.package.init.delete model_package_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="delete_model_package",
        op_kwargs={"ModelPackageName": model_package_name},
    )


async def describe(hub, ctx, model_package_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns a description of the specified model package, which is used to create Amazon SageMaker models or list them on Amazon Web Services Marketplace. To create models in Amazon SageMaker, buyers can subscribe to model packages listed on Amazon Web Services Marketplace.

    Args:
        model_package_name(str): The name or Amazon Resource Name (ARN) of the model package to describe. When you specify a name, the name must have 1 to 63 characters. Valid characters are a-z, A-Z, 0-9, and - (hyphen).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.model.package.init.describe(
                ctx, model_package_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.model.package.init.describe model_package_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_model_package",
        op_kwargs={"ModelPackageName": model_package_name},
    )


async def list_all(
    hub,
    ctx,
    creation_time_after: str = None,
    creation_time_before: str = None,
    max_results: int = None,
    name_contains: str = None,
    model_approval_status: str = None,
    model_package_group_name: str = None,
    model_package_type: str = None,
    next_token: str = None,
    sort_by: str = None,
    sort_order: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the model packages that have been created.

    Args:
        creation_time_after(str, optional): A filter that returns only model packages created after the specified time (timestamp). Defaults to None.
        creation_time_before(str, optional): A filter that returns only model packages created before the specified time (timestamp). Defaults to None.
        max_results(int, optional): The maximum number of model packages to return in the response. Defaults to None.
        name_contains(str, optional): A string in the model package name. This filter returns only model packages whose name contains the specified string. Defaults to None.
        model_approval_status(str, optional): A filter that returns only the model packages with the specified approval status. Defaults to None.
        model_package_group_name(str, optional): A filter that returns only model versions that belong to the specified model group. Defaults to None.
        model_package_type(str, optional): A filter that returns onlyl the model packages of the specified type. This can be one of the following values.    VERSIONED - List only versioned models.    UNVERSIONED - List only unversioined models.    BOTH - List both versioned and unversioned models.  . Defaults to None.
        next_token(str, optional): If the response to a previous ListModelPackages request was truncated, the response includes a NextToken. To retrieve the next set of model packages, use the token in the next request. Defaults to None.
        sort_by(str, optional): The parameter by which to sort the results. The default is CreationTime. Defaults to None.
        sort_order(str, optional): The sort order for the results. The default is Ascending. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.model.package.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.model.package.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_model_packages",
        op_kwargs={
            "CreationTimeAfter": creation_time_after,
            "CreationTimeBefore": creation_time_before,
            "MaxResults": max_results,
            "NameContains": name_contains,
            "ModelApprovalStatus": model_approval_status,
            "ModelPackageGroupName": model_package_group_name,
            "ModelPackageType": model_package_type,
            "NextToken": next_token,
            "SortBy": sort_by,
            "SortOrder": sort_order,
        },
    )


async def update(
    hub,
    ctx,
    model_package_arn: str,
    model_approval_status: str,
    approval_description: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a versioned model.

    Args:
        model_package_arn(str): The Amazon Resource Name (ARN) of the model.
        model_approval_status(str): The approval status of the model.
        approval_description(str, optional): A description for the approval status of the model. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.model.package.init.update(
                ctx, model_package_arn=value, model_approval_status=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.model.package.init.update model_package_arn=value, model_approval_status=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="update_model_package",
        op_kwargs={
            "ModelPackageArn": model_package_arn,
            "ModelApprovalStatus": model_approval_status,
            "ApprovalDescription": approval_description,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def verify(hub, ctx, domain: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns a set of DKIM tokens for a domain identity.  When you execute the VerifyDomainDkim operation, the domain that you specify is added to the list of identities that are associated with your account. This is true even if you haven't already associated the domain with your account by using the VerifyDomainIdentity operation. However, you can't send email from the domain until you either successfully verify it or you successfully set up DKIM for it.  You use the tokens that are generated by this operation to create CNAME records. When Amazon SES detects that you've added these records to the DNS configuration for a domain, you can start sending email from that domain. You can start sending email even if you haven't added the TXT record provided by the VerifyDomainIdentity operation to the DNS configuration for your domain. All email that you send from the domain is authenticated using DKIM. To create the CNAME records for DKIM authentication, use the following values:    Name: token._domainkey.example.com     Type: CNAME    Value: token.dkim.amazonses.com   In the preceding example, replace token with one of the tokens that are generated when you execute this operation. Replace example.com with your domain. Repeat this process for each token that's generated by this operation. You can execute this operation no more than once per second.

    Args:
        domain(str): The name of the domain to be verified for Easy DKIM signing.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.domain.dkim.verify(ctx, domain=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.domain.dkim.verify domain=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="verify_domain_dkim",
        op_kwargs={"Domain": domain},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    project_name: str,
    description: str = None,
    placement_template: Dict = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an empty project with a placement template. A project contains zero or more placements that adhere to the placement template defined in the project.

    Args:
        project_name(str): The name of the project to create.
        description(str, optional): An optional description for the project. Defaults to None.
        placement_template(Dict, optional): The schema defining the placement to be created. A placement template defines placement default attributes and device templates. You cannot add or remove device templates after the project has been created. However, you can update callbackOverrides for the device templates using the UpdateProject API. Defaults to None.
        tags(Dict, optional): Optional tags (metadata key/value pairs) to be associated with the project. For example, { {"key1": "value1", "key2": "value2"} }. For more information, see AWS Tagging Strategies. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot1click_project.project.create(ctx, project_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot1click_project.project.create project_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot1click-projects",
        operation="create_project",
        op_kwargs={
            "projectName": project_name,
            "description": description,
            "placementTemplate": placement_template,
            "tags": tags,
        },
    )


async def delete(hub, ctx, project_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a project. To delete a project, it must not have any placements associated with it.  When you delete a project, all associated data becomes irretrievable.

    Args:
        project_name(str): The name of the empty project to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot1click_project.project.delete(ctx, project_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot1click_project.project.delete project_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot1click-projects",
        operation="delete_project",
        op_kwargs={"projectName": project_name},
    )


async def describe(hub, ctx, project_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns an object describing a project.

    Args:
        project_name(str): The name of the project to be described.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot1click_project.project.describe(ctx, project_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot1click_project.project.describe project_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot1click-projects",
        operation="describe_project",
        op_kwargs={"projectName": project_name},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the AWS IoT 1-Click project(s) associated with your AWS account and region.

    Args:
        next_token(str, optional): The token to retrieve the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return per request. If not set, a default value of 100 is used. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot1click_project.project.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot1click_project.project.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot1click-projects",
        operation="list_projects",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )


async def update(
    hub,
    ctx,
    project_name: str,
    description: str = None,
    placement_template: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a project associated with your AWS account and region. With the exception of device template names, you can pass just the values that need to be updated because the update request will change only the values that are provided. To clear a value, pass the empty string (i.e., "").

    Args:
        project_name(str): The name of the project to be updated.
        description(str, optional): An optional user-defined description for the project. Defaults to None.
        placement_template(Dict, optional): An object defining the project update. Once a project has been created, you cannot add device template names to the project. However, for a given placementTemplate, you can update the associated callbackOverrides for the device definition using this API. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot1click_project.project.update(ctx, project_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot1click_project.project.update project_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot1click-projects",
        operation="update_project",
        op_kwargs={
            "projectName": project_name,
            "description": description,
            "placementTemplate": placement_template,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    repository_name: str,
    registry_id: str = None,
    image_ids: List = None,
    next_token: str = None,
    max_results: int = None,
    filter_: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns metadata about the images in a repository.  Beginning with Docker version 1.9, the Docker client compresses image layers before pushing them to a V2 Docker registry. The output of the docker images command shows the uncompressed image size, so it may return a larger image size than the image sizes returned by DescribeImages.

    Args:
        registry_id(str, optional): The AWS account ID associated with the registry that contains the repository in which to describe images. If you do not specify a registry, the default registry is assumed. Defaults to None.
        repository_name(str): The repository that contains the images to describe.
        image_ids(List, optional): The list of image IDs for the requested repository. Defaults to None.
        next_token(str, optional): The nextToken value returned from a previous paginated DescribeImages request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. This value is null when there are no more results to return. This option cannot be used when you specify images with imageIds. Defaults to None.
        max_results(int, optional): The maximum number of repository results returned by DescribeImages in paginated output. When this parameter is used, DescribeImages only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another DescribeImages request with the returned nextToken value. This value can be between 1 and 1000. If this parameter is not used, then DescribeImages returns up to 100 results and a nextToken value, if applicable. This option cannot be used when you specify images with imageIds. Defaults to None.
        filter_(Dict, optional): The filter key and value with which to filter your DescribeImages results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr.image.init.describe_all(ctx, repository_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr.image.init.describe_all repository_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr",
        operation="describe_images",
        op_kwargs={
            "registryId": registry_id,
            "repositoryName": repository_name,
            "imageIds": image_ids,
            "nextToken": next_token,
            "maxResults": max_results,
            "filter": filter_,
        },
    )


async def list_all(
    hub,
    ctx,
    repository_name: str,
    registry_id: str = None,
    next_token: str = None,
    max_results: int = None,
    filter_: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all the image IDs for the specified repository. You can filter images based on whether or not they are tagged by using the tagStatus filter and specifying either TAGGED, UNTAGGED or ANY. For example, you can filter your results to return only UNTAGGED images and then pipe that result to a BatchDeleteImage operation to delete them. Or, you can filter your results to return only TAGGED images to list all of the tags in your repository.

    Args:
        registry_id(str, optional): The AWS account ID associated with the registry that contains the repository in which to list images. If you do not specify a registry, the default registry is assumed. Defaults to None.
        repository_name(str): The repository with image IDs to be listed.
        next_token(str, optional): The nextToken value returned from a previous paginated ListImages request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. This value is null when there are no more results to return.  This token should be treated as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes. . Defaults to None.
        max_results(int, optional): The maximum number of image results returned by ListImages in paginated output. When this parameter is used, ListImages only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another ListImages request with the returned nextToken value. This value can be between 1 and 1000. If this parameter is not used, then ListImages returns up to 100 results and a nextToken value, if applicable. Defaults to None.
        filter_(Dict, optional): The filter key and value with which to filter your ListImages results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr.image.init.list_all(ctx, repository_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr.image.init.list_all repository_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr",
        operation="list_images",
        op_kwargs={
            "registryId": registry_id,
            "repositoryName": repository_name,
            "nextToken": next_token,
            "maxResults": max_results,
            "filter": filter_,
        },
    )


async def put(
    hub,
    ctx,
    repository_name: str,
    image_manifest: str,
    registry_id: str = None,
    image_manifest_media_type: str = None,
    image_tag: str = None,
    image_digest: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates or updates the image manifest and tags associated with an image. When an image is pushed and all new image layers have been uploaded, the PutImage API is called once to create or update the image manifest and the tags associated with the image.  This operation is used by the Amazon ECR proxy and is not generally used by customers for pulling and pushing images. In most cases, you should use the docker CLI to pull, tag, and push images.

    Args:
        registry_id(str, optional): The AWS account ID associated with the registry that contains the repository in which to put the image. If you do not specify a registry, the default registry is assumed. Defaults to None.
        repository_name(str): The name of the repository in which to put the image.
        image_manifest(str): The image manifest corresponding to the image to be uploaded.
        image_manifest_media_type(str, optional): The media type of the image manifest. If you push an image manifest that does not contain the mediaType field, you must specify the imageManifestMediaType in the request. Defaults to None.
        image_tag(str, optional): The tag to associate with the image. This parameter is required for images that use the Docker Image Manifest V2 Schema 2 or Open Container Initiative (OCI) formats. Defaults to None.
        image_digest(str, optional): The image digest of the image manifest corresponding to the image. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr.image.init.put(
                ctx, repository_name=value, image_manifest=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr.image.init.put repository_name=value, image_manifest=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr",
        operation="put_image",
        op_kwargs={
            "registryId": registry_id,
            "repositoryName": repository_name,
            "imageManifest": image_manifest,
            "imageManifestMediaType": image_manifest_media_type,
            "imageTag": image_tag,
            "imageDigest": image_digest,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, fleet_id: str, peer_vpc_aws_account_id: str, peer_vpc_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Establishes a VPC peering connection between a virtual private cloud (VPC) in an AWS account with the VPC for your Amazon GameLift fleet. VPC peering enables the game servers on your fleet to communicate directly with other AWS resources. You can peer with VPCs in any AWS account that you have access to, including the account that you use to manage your Amazon GameLift fleets. You cannot peer with VPCs that are in different Regions. For more information, see VPC Peering with Amazon GameLift Fleets. Before calling this operation to establish the peering connection, you first need to call CreateVpcPeeringAuthorization and identify the VPC you want to peer with. Once the authorization for the specified VPC is issued, you have 24 hours to establish the connection. These two operations handle all tasks necessary to peer the two VPCs, including acceptance, updating routing tables, etc.  To establish the connection, call this operation from the AWS account that is used to manage the Amazon GameLift fleets. Identify the following values: (1) The ID of the fleet you want to be enable a VPC peering connection for; (2) The AWS account with the VPC that you want to peer with; and (3) The ID of the VPC you want to peer with. This operation is asynchronous. If successful, a VpcPeeringConnection request is created. You can use continuous polling to track the request's status using DescribeVpcPeeringConnections, or by monitoring fleet events for success or failure using DescribeFleetEvents.   Related actions   CreateVpcPeeringAuthorization | DescribeVpcPeeringAuthorizations | DeleteVpcPeeringAuthorization | CreateVpcPeeringConnection | DescribeVpcPeeringConnections | DeleteVpcPeeringConnection | All APIs by task

    Args:
        fleet_id(str): A unique identifier for the fleet. You can use either the fleet ID or ARN value. This tells Amazon GameLift which GameLift VPC to peer with. .
        peer_vpc_aws_account_id(str): A unique identifier for the AWS account with the VPC that you want to peer your Amazon GameLift fleet with. You can find your Account ID in the AWS Management Console under account settings.
        peer_vpc_id(str): A unique identifier for a VPC with resources to be accessed by your GameLift fleet. The VPC must be in the same Region as your fleet. To look up a VPC ID, use the VPC Dashboard in the AWS Management Console. Learn more about VPC peering in VPC Peering with GameLift Fleets.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.vpc_peering.connection.create(
                ctx, fleet_id=value, peer_vpc_aws_account_id=value, peer_vpc_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.vpc_peering.connection.create fleet_id=value, peer_vpc_aws_account_id=value, peer_vpc_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="create_vpc_peering_connection",
        op_kwargs={
            "FleetId": fleet_id,
            "PeerVpcAwsAccountId": peer_vpc_aws_account_id,
            "PeerVpcId": peer_vpc_id,
        },
    )


async def delete(hub, ctx, fleet_id: str, vpc_peering_connection_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes a VPC peering connection. To delete the connection, you must have a valid authorization for the VPC peering connection that you want to delete. You can check for an authorization by calling DescribeVpcPeeringAuthorizations or request a new one using CreateVpcPeeringAuthorization.  Once a valid authorization exists, call this operation from the AWS account that is used to manage the Amazon GameLift fleets. Identify the connection to delete by the connection ID and fleet ID. If successful, the connection is removed.   Related actions   CreateVpcPeeringAuthorization | DescribeVpcPeeringAuthorizations | DeleteVpcPeeringAuthorization | CreateVpcPeeringConnection | DescribeVpcPeeringConnections | DeleteVpcPeeringConnection | All APIs by task

    Args:
        fleet_id(str): A unique identifier for the fleet. This fleet specified must match the fleet referenced in the VPC peering connection record. You can use either the fleet ID or ARN value.
        vpc_peering_connection_id(str): A unique identifier for a VPC peering connection. This value is included in the VpcPeeringConnection object, which can be retrieved by calling DescribeVpcPeeringConnections.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.vpc_peering.connection.delete(
                ctx, fleet_id=value, vpc_peering_connection_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.vpc_peering.connection.delete fleet_id=value, vpc_peering_connection_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="delete_vpc_peering_connection",
        op_kwargs={
            "FleetId": fleet_id,
            "VpcPeeringConnectionId": vpc_peering_connection_id,
        },
    )


async def describe_all(hub, ctx, fleet_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information on VPC peering connections. Use this operation to get peering information for all fleets or for one specific fleet ID.  To retrieve connection information, call this operation from the AWS account that is used to manage the Amazon GameLift fleets. Specify a fleet ID or leave the parameter empty to retrieve all connection records. If successful, the retrieved information includes both active and pending connections. Active connections identify the IpV4 CIDR block that the VPC uses to connect.   Related actions   CreateVpcPeeringAuthorization | DescribeVpcPeeringAuthorizations | DeleteVpcPeeringAuthorization | CreateVpcPeeringConnection | DescribeVpcPeeringConnections | DeleteVpcPeeringConnection | All APIs by task

    Args:
        fleet_id(str, optional): A unique identifier for the fleet. You can use either the fleet ID or ARN value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.vpc_peering.connection.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.vpc_peering.connection.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="describe_vpc_peering_connections",
        op_kwargs={"FleetId": fleet_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a previously created webhook by name. Deleting the webhook stops AWS CodePipeline from starting a pipeline every time an external event occurs. The API returns successfully when trying to delete a webhook that is already deleted. If a deleted webhook is re-created by calling PutWebhook with the same name, it will have a different URL.

    Args:
        name(str): The name of the webhook you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codepipeline.webhook.init.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codepipeline.webhook.init.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codepipeline",
        operation="delete_webhook",
        op_kwargs={"name": name},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets a listing of all the webhooks in this AWS Region for this account. The output lists all webhooks and includes the webhook URL and ARN and the configuration for each webhook.

    Args:
        next_token(str, optional): The token that was returned from the previous ListWebhooks call, which can be used to return the next set of webhooks in the list. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codepipeline.webhook.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codepipeline.webhook.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codepipeline",
        operation="list_webhooks",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )


async def put(hub, ctx, webhook: Dict, tags: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Defines a webhook and returns a unique webhook URL generated by CodePipeline. This URL can be supplied to third party source hosting providers to call every time there's a code change. When CodePipeline receives a POST request on this URL, the pipeline defined in the webhook is started as long as the POST request satisfied the authentication and filtering requirements supplied when defining the webhook. RegisterWebhookWithThirdParty and DeregisterWebhookWithThirdParty APIs can be used to automatically configure supported third parties to call the generated webhook URL.

    Args:
        webhook(Dict): The detail provided in an input file to create the webhook, such as the webhook name, the pipeline name, and the action name. Give the webhook a unique name that helps you identify it. You might name the webhook after the pipeline and action it targets so that you can easily recognize what it's used for later.
        tags(List, optional): The tags for the webhook. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codepipeline.webhook.init.put(ctx, webhook=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codepipeline.webhook.init.put webhook=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codepipeline",
        operation="put_webhook",
        op_kwargs={"webhook": webhook, "tags": tags},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, resource_arn: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns detailed information about recovery points of the type specified by a resource Amazon Resource Name (ARN).

    Args:
        resource_arn(str): An ARN that uniquely identifies a resource. The format of the ARN depends on the resource type.
        next_token(str, optional): The next item following a partial list of returned items. For example, if a request is made to return maxResults number of items, NextToken allows you to return more items in your list starting at the location pointed to by the next token. Defaults to None.
        max_results(int, optional): The maximum number of items to be returned. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.recovery_point.by.resource.list(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.recovery_point.by.resource.list resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="list_recovery_points_by_resource",
        op_kwargs={
            "ResourceArn": resource_arn,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    filters: List = None,
    dry_run: bool = None,
    instance_ids: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more of your linked EC2-Classic instances. This request only returns information about EC2-Classic instances linked to a VPC through ClassicLink. You cannot use this request to return information about other instances.

    Args:
        filters(List, optional): One or more filters.    group-id - The ID of a VPC security group that's associated with the instance.    instance-id - The ID of the instance.    tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    vpc-id - The ID of the VPC to which the instance is linked.  vpc-id - The ID of the VPC that the instance is linked to.  . Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        instance_ids(List, optional): One or more instance IDs. Must be instances linked to a VPC through ClassicLink. Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Constraint: If the value is greater than 1000, we return only 1000 items. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.classic_link.instance.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.classic_link.instance.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_classic_link_instances",
        op_kwargs={
            "Filters": filters,
            "DryRun": dry_run,
            "InstanceIds": instance_ids,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, code_repository_name: str, git_config: Dict, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Git repository as a resource in your Amazon SageMaker account. You can associate the repository with notebook instances so that you can use Git source control for the notebooks you create. The Git repository is a resource in your Amazon SageMaker account, so it can be associated with more than one notebook instance, and it persists independently from the lifecycle of any notebook instances it is associated with. The repository can be hosted either in Amazon Web Services CodeCommit or in any other Git repository.

    Args:
        code_repository_name(str): The name of the Git repository. The name must have 1 to 63 characters. Valid characters are a-z, A-Z, 0-9, and - (hyphen).
        git_config(Dict): Specifies details about the repository, including the URL where the repository is located, the default branch, and credentials to use to access the repository.
        tags(List, optional): An array of key-value pairs. You can use tags to categorize your Amazon Web Services resources in different ways, for example, by purpose, owner, or environment. For more information, see Tagging Amazon Web Services Resources. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.code_repository.create(
                ctx, code_repository_name=value, git_config=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.code_repository.create code_repository_name=value, git_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_code_repository",
        op_kwargs={
            "CodeRepositoryName": code_repository_name,
            "GitConfig": git_config,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, code_repository_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified Git repository from your account.

    Args:
        code_repository_name(str): The name of the Git repository to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.code_repository.delete(
                ctx, code_repository_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.code_repository.delete code_repository_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="delete_code_repository",
        op_kwargs={"CodeRepositoryName": code_repository_name},
    )


async def describe(hub, ctx, code_repository_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets details about the specified Git repository.

    Args:
        code_repository_name(str): The name of the Git repository to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.code_repository.describe(
                ctx, code_repository_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.code_repository.describe code_repository_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_code_repository",
        op_kwargs={"CodeRepositoryName": code_repository_name},
    )


async def list_all(
    hub,
    ctx,
    creation_time_after: str = None,
    creation_time_before: str = None,
    last_modified_time_after: str = None,
    last_modified_time_before: str = None,
    max_results: int = None,
    name_contains: str = None,
    next_token: str = None,
    sort_by: str = None,
    sort_order: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of the Git repositories in your account.

    Args:
        creation_time_after(str, optional): A filter that returns only Git repositories that were created after the specified time. Defaults to None.
        creation_time_before(str, optional): A filter that returns only Git repositories that were created before the specified time. Defaults to None.
        last_modified_time_after(str, optional): A filter that returns only Git repositories that were last modified after the specified time. Defaults to None.
        last_modified_time_before(str, optional): A filter that returns only Git repositories that were last modified before the specified time. Defaults to None.
        max_results(int, optional): The maximum number of Git repositories to return in the response. Defaults to None.
        name_contains(str, optional): A string in the Git repositories name. This filter returns only repositories whose name contains the specified string. Defaults to None.
        next_token(str, optional): If the result of a ListCodeRepositoriesOutput request was truncated, the response includes a NextToken. To get the next set of Git repositories, use the token in the next request. Defaults to None.
        sort_by(str, optional): The field to sort results by. The default is Name. Defaults to None.
        sort_order(str, optional): The sort order for results. The default is Ascending. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.code_repository.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.code_repository.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_code_repositories",
        op_kwargs={
            "CreationTimeAfter": creation_time_after,
            "CreationTimeBefore": creation_time_before,
            "LastModifiedTimeAfter": last_modified_time_after,
            "LastModifiedTimeBefore": last_modified_time_before,
            "MaxResults": max_results,
            "NameContains": name_contains,
            "NextToken": next_token,
            "SortBy": sort_by,
            "SortOrder": sort_order,
        },
    )


async def update(hub, ctx, code_repository_name: str, git_config: Dict = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified Git repository with the specified values.

    Args:
        code_repository_name(str): The name of the Git repository to update.
        git_config(Dict, optional): The configuration of the git repository, including the URL and the Amazon Resource Name (ARN) of the Amazon Web Services Secrets Manager secret that contains the credentials used to access the repository. The secret must have a staging label of AWSCURRENT and must be in the following format:  {"username": UserName, "password": Password} . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.code_repository.update(
                ctx, code_repository_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.code_repository.update code_repository_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="update_code_repository",
        op_kwargs={"CodeRepositoryName": code_repository_name, "GitConfig": git_config},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    thing_name: str,
    status: str = None,
    namespace_id: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the job executions for the specified thing.

    Args:
        thing_name(str): The thing name.
        status(str, optional): An optional filter that lets you search for jobs that have the specified status. Defaults to None.
        namespace_id(str, optional): The namespace used to indicate that a job is a customer-managed job. When you specify a value for this parameter, AWS IoT Core sends jobs notifications to MQTT topics that contain the value in the following format.  $aws/things/THING_NAME/jobs/JOB_ID/notify-namespace-NAMESPACE_ID/   The namespaceId feature is in public preview. . Defaults to None.
        max_results(int, optional): The maximum number of results to be returned per request. Defaults to None.
        next_token(str, optional): The token to retrieve the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.job.execution.for_.thing.list(ctx, thing_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.job.execution.for_.thing.list thing_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_job_executions_for_thing",
        op_kwargs={
            "thingName": thing_name,
            "status": status,
            "namespaceId": namespace_id,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, collection_name: str, geofence_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the geofence details from a geofence collection.

    Args:
        collection_name(str): The geofence collection storing the target geofence.
        geofence_id(str): The geofence you're retrieving details for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.geofence.init.get(
                ctx, collection_name=value, geofence_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.geofence.init.get collection_name=value, geofence_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="get_geofence",
        op_kwargs={"CollectionName": collection_name, "GeofenceId": geofence_id},
    )


async def list_all(hub, ctx, collection_name: str, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists geofences stored in a given geofence collection.

    Args:
        collection_name(str): The name of the geofence collection storing the list of geofences.
        next_token(str, optional): The pagination token specifying which page of results to return in the response. If no token is provided, the default page is the first page.  Default value: null . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.geofence.init.list_all(ctx, collection_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.geofence.init.list_all collection_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="list_geofences",
        op_kwargs={"CollectionName": collection_name, "NextToken": next_token},
    )


async def put(hub, ctx, collection_name: str, geofence_id: str, geometry: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Stores a geofence geometry in a given geofence collection, or updates the geometry of an existing geofence if a geofence ID is included in the request.

    Args:
        collection_name(str): The geofence collection to store the geofence in.
        geofence_id(str): An identifier for the geofence. For example, ExampleGeofence-1.
        geometry(Dict): Contains the polygon details to specify the position of the geofence.  Each geofence polygon can have a maximum of 1,000 vertices. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.geofence.init.put(
                ctx, collection_name=value, geofence_id=value, geometry=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.geofence.init.put collection_name=value, geofence_id=value, geometry=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="put_geofence",
        op_kwargs={
            "CollectionName": collection_name,
            "GeofenceId": geofence_id,
            "Geometry": geometry,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    input_record_tables: List,
    parameters: Dict,
    role: str,
    description: str = None,
    glue_version: str = None,
    max_capacity: float = None,
    worker_type: str = None,
    number_of_workers: int = None,
    timeout: int = None,
    max_retries: int = None,
    tags: Dict = None,
    transform_encryption: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Glue machine learning transform. This operation creates the transform and all the necessary parameters to train it. Call this operation as the first step in the process of using a machine learning transform (such as the FindMatches transform) for deduplicating data. You can provide an optional Description, in addition to the parameters that you want to use for your algorithm. You must also specify certain parameters for the tasks that Glue runs on your behalf as part of learning from your data and creating a high-quality machine learning transform. These parameters include Role, and optionally, AllocatedCapacity, Timeout, and MaxRetries. For more information, see Jobs.

    Args:
        name(str): The unique name that you give the transform when you create it.
        description(str, optional): A description of the machine learning transform that is being defined. The default is an empty string. Defaults to None.
        input_record_tables(List): A list of Glue table definitions used by the transform.
        parameters(Dict): The algorithmic parameters that are specific to the transform type used. Conditionally dependent on the transform type.
        role(str): The name or Amazon Resource Name (ARN) of the IAM role with the required permissions. The required permissions include both Glue service role permissions to Glue resources, and Amazon S3 permissions required by the transform.    This role needs Glue service role permissions to allow access to resources in Glue. See Attach a Policy to IAM Users That Access Glue.   This role needs permission to your Amazon Simple Storage Service (Amazon S3) sources, targets, temporary directory, scripts, and any libraries used by the task run for this transform.  .
        glue_version(str, optional): This value determines which version of Glue this machine learning transform is compatible with. Glue 1.0 is recommended for most customers. If the value is not set, the Glue compatibility defaults to Glue 0.9. For more information, see Glue Versions in the developer guide. Defaults to None.
        max_capacity(float, optional): The number of Glue data processing units (DPUs) that are allocated to task runs for this transform. You can allocate from 2 to 100 DPUs; the default is 10. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB of memory. For more information, see the Glue pricing page.   MaxCapacity is a mutually exclusive option with NumberOfWorkers and WorkerType.   If either NumberOfWorkers or WorkerType is set, then MaxCapacity cannot be set.   If MaxCapacity is set then neither NumberOfWorkers or WorkerType can be set.   If WorkerType is set, then NumberOfWorkers is required (and vice versa).    MaxCapacity and NumberOfWorkers must both be at least 1.   When the WorkerType field is set to a value other than Standard, the MaxCapacity field is set automatically and becomes read-only. When the WorkerType field is set to a value other than Standard, the MaxCapacity field is set automatically and becomes read-only. Defaults to None.
        worker_type(str, optional): The type of predefined worker that is allocated when this task runs. Accepts a value of Standard, G.1X, or G.2X.   For the Standard worker type, each worker provides 4 vCPU, 16 GB of memory and a 50GB disk, and 2 executors per worker.   For the G.1X worker type, each worker provides 4 vCPU, 16 GB of memory and a 64GB disk, and 1 executor per worker.   For the G.2X worker type, each worker provides 8 vCPU, 32 GB of memory and a 128GB disk, and 1 executor per worker.    MaxCapacity is a mutually exclusive option with NumberOfWorkers and WorkerType.   If either NumberOfWorkers or WorkerType is set, then MaxCapacity cannot be set.   If MaxCapacity is set then neither NumberOfWorkers or WorkerType can be set.   If WorkerType is set, then NumberOfWorkers is required (and vice versa).    MaxCapacity and NumberOfWorkers must both be at least 1.  . Defaults to None.
        number_of_workers(int, optional): The number of workers of a defined workerType that are allocated when this task runs. If WorkerType is set, then NumberOfWorkers is required (and vice versa). Defaults to None.
        timeout(int, optional): The timeout of the task run for this transform in minutes. This is the maximum time that a task run for this transform can consume resources before it is terminated and enters TIMEOUT status. The default is 2,880 minutes (48 hours). Defaults to None.
        max_retries(int, optional): The maximum number of times to retry a task for this transform after a task run fails. Defaults to None.
        tags(Dict, optional): The tags to use with this machine learning transform. You may use tags to limit access to the machine learning transform. For more information about tags in Glue, see Amazon Web Services Tags in Glue in the developer guide. Defaults to None.
        transform_encryption(Dict, optional): The encryption-at-rest settings of the transform that apply to accessing user data. Machine learning transforms can access user data encrypted in Amazon S3 using KMS. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.ml.transform.create(
                ctx, name=value, input_record_tables=value, parameters=value, role=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.ml.transform.create name=value, input_record_tables=value, parameters=value, role=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="create_ml_transform",
        op_kwargs={
            "Name": name,
            "Description": description,
            "InputRecordTables": input_record_tables,
            "Parameters": parameters,
            "Role": role,
            "GlueVersion": glue_version,
            "MaxCapacity": max_capacity,
            "WorkerType": worker_type,
            "NumberOfWorkers": number_of_workers,
            "Timeout": timeout,
            "MaxRetries": max_retries,
            "Tags": tags,
            "TransformEncryption": transform_encryption,
        },
    )


async def delete(hub, ctx, transform_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an Glue machine learning transform. Machine learning transforms are a special type of transform that use machine learning to learn the details of the transformation to be performed by learning from examples provided by humans. These transformations are then saved by Glue. If you no longer need a transform, you can delete it by calling DeleteMLTransforms. However, any Glue jobs that still reference the deleted transform will no longer succeed.

    Args:
        transform_id(str): The unique identifier of the transform to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.ml.transform.delete(ctx, transform_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.ml.transform.delete transform_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="delete_ml_transform",
        op_kwargs={"TransformId": transform_id},
    )


async def get(hub, ctx, transform_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets an Glue machine learning transform artifact and all its corresponding metadata. Machine learning transforms are a special type of transform that use machine learning to learn the details of the transformation to be performed by learning from examples provided by humans. These transformations are then saved by Glue. You can retrieve their metadata by calling GetMLTransform.

    Args:
        transform_id(str): The unique identifier of the transform, generated at the time that the transform was created.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.ml.transform.get(ctx, transform_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.ml.transform.get transform_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_ml_transform",
        op_kwargs={"TransformId": transform_id},
    )


async def get_all(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    filter_: Dict = None,
    sort: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a sortable, filterable list of existing Glue machine learning transforms. Machine learning transforms are a special type of transform that use machine learning to learn the details of the transformation to be performed by learning from examples provided by humans. These transformations are then saved by Glue, and you can retrieve their metadata by calling GetMLTransforms.

    Args:
        next_token(str, optional): A paginated token to offset the results. Defaults to None.
        max_results(int, optional): The maximum number of results to return. Defaults to None.
        filter_(Dict, optional): The filter transformation criteria. Defaults to None.
        sort(Dict, optional): The sorting criteria. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.ml.transform.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.ml.transform.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_ml_transforms",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "Filter": filter_,
            "Sort": sort,
        },
    )


async def list_all(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    filter_: Dict = None,
    sort: Dict = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Retrieves a sortable, filterable list of existing Glue machine learning transforms in this Amazon Web Services account, or the resources with the specified tag. This operation takes the optional Tags field, which you can use as a filter of the responses so that tagged resources can be retrieved as a group. If you choose to use tag filtering, only resources with the tags are retrieved.

    Args:
        next_token(str, optional): A continuation token, if this is a continuation request. Defaults to None.
        max_results(int, optional): The maximum size of a list to return. Defaults to None.
        filter_(Dict, optional): A TransformFilterCriteria used to filter the machine learning transforms. Defaults to None.
        sort(Dict, optional): A TransformSortCriteria used to sort the machine learning transforms. Defaults to None.
        tags(Dict, optional): Specifies to return only these tagged resources. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.ml.transform.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.ml.transform.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="list_ml_transforms",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "Filter": filter_,
            "Sort": sort,
            "Tags": tags,
        },
    )


async def update(
    hub,
    ctx,
    transform_id: str,
    name: str = None,
    description: str = None,
    parameters: Dict = None,
    role: str = None,
    glue_version: str = None,
    max_capacity: float = None,
    worker_type: str = None,
    number_of_workers: int = None,
    timeout: int = None,
    max_retries: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing machine learning transform. Call this operation to tune the algorithm parameters to achieve better results. After calling this operation, you can call the StartMLEvaluationTaskRun operation to assess how well your new parameters achieved your goals (such as improving the quality of your machine learning transform, or making it more cost-effective).

    Args:
        transform_id(str): A unique identifier that was generated when the transform was created.
        name(str, optional): The unique name that you gave the transform when you created it. Defaults to None.
        description(str, optional): A description of the transform. The default is an empty string. Defaults to None.
        parameters(Dict, optional): The configuration parameters that are specific to the transform type (algorithm) used. Conditionally dependent on the transform type. Defaults to None.
        role(str, optional): The name or Amazon Resource Name (ARN) of the IAM role with the required permissions. Defaults to None.
        glue_version(str, optional): This value determines which version of Glue this machine learning transform is compatible with. Glue 1.0 is recommended for most customers. If the value is not set, the Glue compatibility defaults to Glue 0.9. For more information, see Glue Versions in the developer guide. Defaults to None.
        max_capacity(float, optional): The number of Glue data processing units (DPUs) that are allocated to task runs for this transform. You can allocate from 2 to 100 DPUs; the default is 10. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB of memory. For more information, see the Glue pricing page.  When the WorkerType field is set to a value other than Standard, the MaxCapacity field is set automatically and becomes read-only. Defaults to None.
        worker_type(str, optional): The type of predefined worker that is allocated when this task runs. Accepts a value of Standard, G.1X, or G.2X.   For the Standard worker type, each worker provides 4 vCPU, 16 GB of memory and a 50GB disk, and 2 executors per worker.   For the G.1X worker type, each worker provides 4 vCPU, 16 GB of memory and a 64GB disk, and 1 executor per worker.   For the G.2X worker type, each worker provides 8 vCPU, 32 GB of memory and a 128GB disk, and 1 executor per worker.  . Defaults to None.
        number_of_workers(int, optional): The number of workers of a defined workerType that are allocated when this task runs. Defaults to None.
        timeout(int, optional): The timeout for a task run for this transform in minutes. This is the maximum time that a task run for this transform can consume resources before it is terminated and enters TIMEOUT status. The default is 2,880 minutes (48 hours). Defaults to None.
        max_retries(int, optional): The maximum number of times to retry a task for this transform after a task run fails. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.ml.transform.update(ctx, transform_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.ml.transform.update transform_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="update_ml_transform",
        op_kwargs={
            "TransformId": transform_id,
            "Name": name,
            "Description": description,
            "Parameters": parameters,
            "Role": role,
            "GlueVersion": glue_version,
            "MaxCapacity": max_capacity,
            "WorkerType": worker_type,
            "NumberOfWorkers": number_of_workers,
            "Timeout": timeout,
            "MaxRetries": max_retries,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: List) -> None:
    r"""
    **Autogenerated function**

    Associate a set of tags with an Amazon DynamoDB resource. You can then activate these user-defined tags so that they appear on the Billing and Cost Management console for cost allocation tracking. You can call TagResource up to five times per second, per account.  For an overview on tagging DynamoDB resources, see Tagging for DynamoDB in the Amazon DynamoDB Developer Guide.

    Args:
        resource_arn(str): Identifies the Amazon DynamoDB resource to which tags should be added. This value is an Amazon Resource Name (ARN).
        tags(List): The tags to be assigned to the Amazon DynamoDB resource.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="tag_resource",
        op_kwargs={"ResourceArn": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> None:
    r"""
    **Autogenerated function**

    Removes the association of tags from an Amazon DynamoDB resource. You can call UntagResource up to five times per second, per account.  For an overview on tagging DynamoDB resources, see Tagging for DynamoDB in the Amazon DynamoDB Developer Guide.

    Args:
        resource_arn(str): The DynamoDB resource that the tags will be removed from. This value is an Amazon Resource Name (ARN).
        tag_keys(List): A list of tag keys. Existing tags of the resource whose keys are members of this list will be removed from the DynamoDB resource.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.resource.untag(ctx, resource_arn=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="untag_resource",
        op_kwargs={"ResourceArn": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    protection_group_id: str,
    aggregation: str,
    pattern: str,
    resource_type: str = None,
    members: List = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a grouping of protected resources so they can be handled as a collective. This resource grouping improves the accuracy of detection and reduces false positives.

    Args:
        protection_group_id(str): The name of the protection group. You use this to identify the protection group in lists and to manage the protection group, for example to update, delete, or describe it. .
        aggregation(str): Defines how Shield combines resource data for the group in order to detect, mitigate, and report events.   Sum - Use the total traffic across the group. This is a good choice for most cases. Examples include Elastic IP addresses for EC2 instances that scale manually or automatically.   Mean - Use the average of the traffic across the group. This is a good choice for resources that share traffic uniformly. Examples include accelerators and load balancers.   Max - Use the highest traffic from each resource. This is useful for resources that don't share traffic and for resources that share that traffic in a non-uniform way. Examples include Amazon CloudFront and origin resources for CloudFront distributions.  .
        pattern(str): The criteria to use to choose the protected resources for inclusion in the group. You can include all resources that have protections, provide a list of resource Amazon Resource Names (ARNs), or include all resources of a specified resource type. .
        resource_type(str, optional): The resource type to include in the protection group. All protected resources of this type are included in the protection group. Newly protected resources of this type are automatically added to the group. You must set this when you set Pattern to BY_RESOURCE_TYPE and you must not set it for any other Pattern setting. . Defaults to None.
        members(List, optional): The Amazon Resource Names (ARNs) of the resources to include in the protection group. You must set this when you set Pattern to ARBITRARY and you must not set it for any other Pattern setting. . Defaults to None.
        tags(List, optional): One or more tag key-value pairs for the protection group. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.shield.protection.group.create(
                ctx, protection_group_id=value, aggregation=value, pattern=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.shield.protection.group.create protection_group_id=value, aggregation=value, pattern=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="shield",
        operation="create_protection_group",
        op_kwargs={
            "ProtectionGroupId": protection_group_id,
            "Aggregation": aggregation,
            "Pattern": pattern,
            "ResourceType": resource_type,
            "Members": members,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, protection_group_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes the specified protection group.

    Args:
        protection_group_id(str): The name of the protection group. You use this to identify the protection group in lists and to manage the protection group, for example to update, delete, or describe it. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.shield.protection.group.delete(ctx, protection_group_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.shield.protection.group.delete protection_group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="shield",
        operation="delete_protection_group",
        op_kwargs={"ProtectionGroupId": protection_group_id},
    )


async def describe(hub, ctx, protection_group_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the specification for the specified protection group.

    Args:
        protection_group_id(str): The name of the protection group. You use this to identify the protection group in lists and to manage the protection group, for example to update, delete, or describe it. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.shield.protection.group.describe(ctx, protection_group_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.shield.protection.group.describe protection_group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="shield",
        operation="describe_protection_group",
        op_kwargs={"ProtectionGroupId": protection_group_id},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the ProtectionGroup objects for the account.

    Args:
        next_token(str, optional): The next token value from a previous call to ListProtectionGroups. Pass null if this is the first call. Defaults to None.
        max_results(int, optional): The maximum number of ProtectionGroup objects to return. If you leave this blank, Shield Advanced returns the first 20 results. This is a maximum value. Shield Advanced might return the results in smaller batches. That is, the number of objects returned could be less than MaxResults, even if there are still more objects yet to return. If there are more objects to return, Shield Advanced returns a value in NextToken that you can use in your next request, to get the next batch of objects. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.shield.protection.group.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.shield.protection.group.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="shield",
        operation="list_protection_groups",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )


async def update(
    hub,
    ctx,
    protection_group_id: str,
    aggregation: str,
    pattern: str,
    resource_type: str = None,
    members: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing protection group. A protection group is a grouping of protected resources so they can be handled as a collective. This resource grouping improves the accuracy of detection and reduces false positives.

    Args:
        protection_group_id(str): The name of the protection group. You use this to identify the protection group in lists and to manage the protection group, for example to update, delete, or describe it. .
        aggregation(str): Defines how Shield combines resource data for the group in order to detect, mitigate, and report events.   Sum - Use the total traffic across the group. This is a good choice for most cases. Examples include Elastic IP addresses for EC2 instances that scale manually or automatically.   Mean - Use the average of the traffic across the group. This is a good choice for resources that share traffic uniformly. Examples include accelerators and load balancers.   Max - Use the highest traffic from each resource. This is useful for resources that don't share traffic and for resources that share that traffic in a non-uniform way. Examples include Amazon CloudFront distributions and origin resources for CloudFront distributions.  .
        pattern(str): The criteria to use to choose the protected resources for inclusion in the group. You can include all resources that have protections, provide a list of resource Amazon Resource Names (ARNs), or include all resources of a specified resource type.
        resource_type(str, optional): The resource type to include in the protection group. All protected resources of this type are included in the protection group. You must set this when you set Pattern to BY_RESOURCE_TYPE and you must not set it for any other Pattern setting. . Defaults to None.
        members(List, optional): The Amazon Resource Names (ARNs) of the resources to include in the protection group. You must set this when you set Pattern to ARBITRARY and you must not set it for any other Pattern setting. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.shield.protection.group.update(
                ctx, protection_group_id=value, aggregation=value, pattern=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.shield.protection.group.update protection_group_id=value, aggregation=value, pattern=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="shield",
        operation="update_protection_group",
        op_kwargs={
            "ProtectionGroupId": protection_group_id,
            "Aggregation": aggregation,
            "Pattern": pattern,
            "ResourceType": resource_type,
            "Members": members,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, insight_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

     Returns the most recent feedback submitted in the current AWS account and Region.

    Args:
        insight_id(str, optional):  The ID of the insight for which the feedback was provided. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devop_guru.feedback.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devop_guru.feedback.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devops-guru",
        operation="describe_feedback",
        op_kwargs={"InsightId": insight_id},
    )


async def put(hub, ctx, insight_feedback: Dict = None) -> Dict:
    r"""
    **Autogenerated function**

     Collects customer feedback about the specified insight.

    Args:
        insight_feedback(Dict, optional):  The feedback from customers is about the recommendations in this insight. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devop_guru.feedback.put(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devop_guru.feedback.put
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devops-guru",
        operation="put_feedback",
        op_kwargs={"InsightFeedback": insight_feedback},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def generate(
    hub, ctx, app_id: str, backend_environment_name: str, resource_name: str
) -> Dict:
    r"""
    **Autogenerated function**

    Generates a model schema for an existing backend API resource.

    Args:
        app_id(str): The app ID.
        backend_environment_name(str): The name of the backend environment.
        resource_name(str): The name of this resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplifybackend.backend.api.model.generate(
                ctx, app_id=value, backend_environment_name=value, resource_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplifybackend.backend.api.model.generate app_id=value, backend_environment_name=value, resource_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplifybackend",
        operation="generate_backend_api_models",
        op_kwargs={
            "AppId": app_id,
            "BackendEnvironmentName": backend_environment_name,
            "ResourceName": resource_name,
        },
    )


async def get_all(
    hub, ctx, app_id: str, backend_environment_name: str, resource_name: str
) -> Dict:
    r"""
    **Autogenerated function**

    Generates a model schema for existing backend API resource.

    Args:
        app_id(str): The app ID.
        backend_environment_name(str): The name of the backend environment.
        resource_name(str): The name of this resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplifybackend.backend.api.model.get_all(
                ctx, app_id=value, backend_environment_name=value, resource_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplifybackend.backend.api.model.get_all app_id=value, backend_environment_name=value, resource_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplifybackend",
        operation="get_backend_api_models",
        op_kwargs={
            "AppId": app_id,
            "BackendEnvironmentName": backend_environment_name,
            "ResourceName": resource_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(
    hub, ctx, policy_name: str, auto_scaling_group_name: str = None
) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified scaling policy. Deleting either a step scaling policy or a simple scaling policy deletes the underlying alarm action, but does not delete the alarm, even if it no longer has an associated action. For more information, see Deleting a scaling policy in the Amazon EC2 Auto Scaling User Guide.

    Args:
        auto_scaling_group_name(str, optional): The name of the Auto Scaling group. Defaults to None.
        policy_name(str): The name or Amazon Resource Name (ARN) of the policy.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.policy.delete(ctx, policy_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.policy.delete policy_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="delete_policy",
        op_kwargs={
            "AutoScalingGroupName": auto_scaling_group_name,
            "PolicyName": policy_name,
        },
    )


async def describe_all(
    hub,
    ctx,
    auto_scaling_group_name: str = None,
    policy_names: List = None,
    policy_types: List = None,
    next_token: str = None,
    max_records: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the scaling policies in the account and Region.

    Args:
        auto_scaling_group_name(str, optional): The name of the Auto Scaling group. Defaults to None.
        policy_names(List, optional): The names of one or more policies. If you omit this parameter, all policies are described. If a group name is provided, the results are limited to that group. If you specify an unknown policy name, it is ignored with no error. Array Members: Maximum number of 50 items. Defaults to None.
        policy_types(List, optional): One or more policy types. The valid values are SimpleScaling, StepScaling, TargetTrackingScaling, and PredictiveScaling. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.
        max_records(int, optional): The maximum number of items to be returned with each call. The default value is 50 and the maximum value is 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.policy.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.policy.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="describe_policies",
        op_kwargs={
            "AutoScalingGroupName": auto_scaling_group_name,
            "PolicyNames": policy_names,
            "PolicyTypes": policy_types,
            "NextToken": next_token,
            "MaxRecords": max_records,
        },
    )


async def execute(
    hub,
    ctx,
    policy_name: str,
    auto_scaling_group_name: str = None,
    honor_cooldown: bool = None,
    metric_value: float = None,
    breach_threshold: float = None,
) -> None:
    r"""
    **Autogenerated function**

    Executes the specified policy. This can be useful for testing the design of your scaling policy.

    Args:
        auto_scaling_group_name(str, optional): The name of the Auto Scaling group. Defaults to None.
        policy_name(str): The name or ARN of the policy.
        honor_cooldown(bool, optional): Indicates whether Amazon EC2 Auto Scaling waits for the cooldown period to complete before executing the policy. Valid only if the policy type is SimpleScaling. For more information, see Scaling cooldowns for Amazon EC2 Auto Scaling in the Amazon EC2 Auto Scaling User Guide. Defaults to None.
        metric_value(float, optional): The metric value to compare to BreachThreshold. This enables you to execute a policy of type StepScaling and determine which step adjustment to use. For example, if the breach threshold is 50 and you want to use a step adjustment with a lower bound of 0 and an upper bound of 10, you can set the metric value to 59. If you specify a metric value that doesn't correspond to a step adjustment for the policy, the call returns an error. Required if the policy type is StepScaling and not supported otherwise. Defaults to None.
        breach_threshold(float, optional): The breach threshold for the alarm. Required if the policy type is StepScaling and not supported otherwise. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.policy.execute(ctx, policy_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.policy.execute policy_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="execute_policy",
        op_kwargs={
            "AutoScalingGroupName": auto_scaling_group_name,
            "PolicyName": policy_name,
            "HonorCooldown": honor_cooldown,
            "MetricValue": metric_value,
            "BreachThreshold": breach_threshold,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub,
    ctx,
    job_id: str,
    service_namespace: str,
    max_items: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    After you generate a group or policy report using the GenerateServiceLastAccessedDetails operation, you can use the JobId parameter in GetServiceLastAccessedDetailsWithEntities. This operation retrieves the status of your report job and a list of entities that could have used group or policy permissions to access the specified service.    Group – For a group report, this operation returns a list of users in the group that could have used the group’s policies in an attempt to access the service.    Policy – For a policy report, this operation returns a list of entities (users or roles) that could have used the policy in an attempt to access the service.   You can also use this operation for user or role reports to retrieve details about those entities. If the operation fails, the GetServiceLastAccessedDetailsWithEntities operation returns the reason that it failed. By default, the list of associated entities is sorted by date, with the most recent access listed first.

    Args:
        job_id(str): The ID of the request generated by the GenerateServiceLastAccessedDetails operation.
        service_namespace(str): The service namespace for an Amazon Web Services service. Provide the service namespace to learn when the IAM entity last attempted to access the specified service. To learn the service namespace for a service, see Actions, resources, and condition keys for Amazon Web Services services in the IAM User Guide. Choose the name of the service to view details for that service. In the first paragraph, find the service prefix. For example, (service prefix: a4b). For more information about service namespaces, see Amazon Web Services service namespaces in the Amazon Web Services General Reference.
        max_items(int, optional): Use this only when paginating results to indicate the maximum number of items you want in the response. If additional items exist beyond the maximum you specify, the IsTruncated response element is true. If you do not include this parameter, the number of items defaults to 100. Note that IAM might return fewer results, even when there are more results available. In that case, the IsTruncated response element returns true, and Marker contains a value to include in the subsequent call that tells the service where to continue from. Defaults to None.
        marker(str, optional): Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the Marker element in the response that you received to indicate where the next call should start. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.service.last_accessed_detail.with_entity.get_all(
                ctx, job_id=value, service_namespace=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.service.last_accessed_detail.with_entity.get_all job_id=value, service_namespace=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="get_service_last_accessed_details_with_entities",
        op_kwargs={
            "JobId": job_id,
            "ServiceNamespace": service_namespace,
            "MaxItems": max_items,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Deletes one or more builds.

    Args:
        ids(List): The IDs of the builds to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.delete_build.batch(ctx, ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.delete_build.batch ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codebuild",
        operation="batch_delete_builds",
        op_kwargs={"ids": ids},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, device_arn: str, device_usage_type: str) -> Dict:
    r"""
    **Autogenerated function**

    When this action is called for a specified shared device, it allows authorized users to delete the device's entire previous history of voice input data and associated response data. This action can be called once every 24 hours for a specific shared device.

    Args:
        device_arn(str): The ARN of the device.
        device_usage_type(str): The type of usage data to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.device.usage_data.delete(
                ctx, device_arn=value, device_usage_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.device.usage_data.delete device_arn=value, device_usage_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="delete_device_usage_data",
        op_kwargs={"DeviceArn": device_arn, "DeviceUsageType": device_usage_type},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, resource_arn: str, limit: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    List the tags for an App Mesh resource.

    Args:
        limit(int, optional): The maximum number of tag results returned by ListTagsForResource in paginated output. When this parameter is used, ListTagsForResource returns only limit results in a single page along with a nextToken response element. You can see the remaining results of the initial request by sending another ListTagsForResource request with the returned nextToken value. This value can be between 1 and 100. If you don't use this parameter, ListTagsForResource returns up to 100 results and a nextToken value if applicable. Defaults to None.
        next_token(str, optional): The nextToken value returned from a previous paginated ListTagsForResource request where limit was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. Defaults to None.
        resource_arn(str): The Amazon Resource Name (ARN) that identifies the resource to list the tags for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appmesh.tags_for_resource.list(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appmesh.tags_for_resource.list resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appmesh",
        operation="list_tags_for_resource",
        op_kwargs={
            "limit": limit,
            "nextToken": next_token,
            "resourceArn": resource_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    cluster_identifier: str,
    node_type: str,
    master_username: str,
    master_user_password: str,
    db_name: str = None,
    cluster_type: str = None,
    cluster_security_groups: List = None,
    vpc_security_group_ids: List = None,
    cluster_subnet_group_name: str = None,
    availability_zone: str = None,
    preferred_maintenance_window: str = None,
    cluster_parameter_group_name: str = None,
    automated_snapshot_retention_period: int = None,
    manual_snapshot_retention_period: int = None,
    port: int = None,
    cluster_version: str = None,
    allow_version_upgrade: bool = None,
    number_of_nodes: int = None,
    publicly_accessible: bool = None,
    encrypted: bool = None,
    hsm_client_certificate_identifier: str = None,
    hsm_configuration_identifier: str = None,
    elastic_ip: str = None,
    tags: List = None,
    kms_key_id: str = None,
    enhanced_vpc_routing: bool = None,
    additional_info: str = None,
    iam_roles: List = None,
    maintenance_track_name: str = None,
    snapshot_schedule_identifier: str = None,
    availability_zone_relocation: bool = None,
    aqua_configuration_status: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new cluster with the specified parameters. To create a cluster in Virtual Private Cloud (VPC), you must provide a cluster subnet group name. The cluster subnet group identifies the subnets of your VPC that Amazon Redshift uses when creating the cluster. For more information about managing clusters, go to Amazon Redshift Clusters in the Amazon Redshift Cluster Management Guide.

    Args:
        db_name(str, optional): The name of the first database to be created when the cluster is created. To create additional databases after the cluster is created, connect to the cluster with a SQL client and use SQL commands to create a database. For more information, go to Create a Database in the Amazon Redshift Database Developer Guide.  Default: dev  Constraints:   Must contain 1 to 64 alphanumeric characters.   Must contain only lowercase letters.   Cannot be a word that is reserved by the service. A list of reserved words can be found in Reserved Words in the Amazon Redshift Database Developer Guide.   . Defaults to None.
        cluster_identifier(str): A unique identifier for the cluster. You use this identifier to refer to the cluster for any subsequent cluster operations such as deleting or modifying. The identifier also appears in the Amazon Redshift console. Constraints:   Must contain from 1 to 63 alphanumeric characters or hyphens.   Alphabetic characters must be lowercase.   First character must be a letter.   Cannot end with a hyphen or contain two consecutive hyphens.   Must be unique for all clusters within an Amazon Web Services account.   Example: myexamplecluster .
        cluster_type(str, optional): The type of the cluster. When cluster type is specified as    single-node, the NumberOfNodes parameter is not required.    multi-node, the NumberOfNodes parameter is required.   Valid Values: multi-node | single-node  Default: multi-node . Defaults to None.
        node_type(str): The node type to be provisioned for the cluster. For information about node types, go to  Working with Clusters in the Amazon Redshift Cluster Management Guide.  Valid Values: ds2.xlarge | ds2.8xlarge | dc1.large | dc1.8xlarge | dc2.large | dc2.8xlarge | ra3.xlplus | ra3.4xlarge | ra3.16xlarge .
        master_username(str): The user name associated with the admin user account for the cluster that is being created. Constraints:   Must be 1 - 128 alphanumeric characters. The user name can't be PUBLIC.   First character must be a letter.   Cannot be a reserved word. A list of reserved words can be found in Reserved Words in the Amazon Redshift Database Developer Guide.   .
        master_user_password(str): The password associated with the admin user account for the cluster that is being created. Constraints:   Must be between 8 and 64 characters in length.   Must contain at least one uppercase letter.   Must contain at least one lowercase letter.   Must contain one number.   Can be any printable ASCII character (ASCII code 33 to 126) except ' (single quote), " (double quote), \, /, @, or space.  .
        cluster_security_groups(List, optional): A list of security groups to be associated with this cluster. Default: The default cluster security group for Amazon Redshift. Defaults to None.
        vpc_security_group_ids(List, optional): A list of Virtual Private Cloud (VPC) security groups to be associated with the cluster. Default: The default VPC security group is associated with the cluster. Defaults to None.
        cluster_subnet_group_name(str, optional): The name of a cluster subnet group to be associated with this cluster. If this parameter is not provided the resulting cluster will be deployed outside virtual private cloud (VPC). Defaults to None.
        availability_zone(str, optional): The EC2 Availability Zone (AZ) in which you want Amazon Redshift to provision the cluster. For example, if you have several EC2 instances running in a specific Availability Zone, then you might want the cluster to be provisioned in the same zone in order to decrease network latency. Default: A random, system-chosen Availability Zone in the region that is specified by the endpoint. Example: us-east-2d  Constraint: The specified Availability Zone must be in the same region as the current endpoint. Defaults to None.
        preferred_maintenance_window(str, optional): The weekly time range (in UTC) during which automated cluster maintenance can occur.  Format: ddd:hh24:mi-ddd:hh24:mi   Default: A 30-minute window selected at random from an 8-hour block of time per region, occurring on a random day of the week. For more information about the time blocks for each region, see Maintenance Windows in Amazon Redshift Cluster Management Guide. Valid Days: Mon | Tue | Wed | Thu | Fri | Sat | Sun Constraints: Minimum 30-minute window. Defaults to None.
        cluster_parameter_group_name(str, optional): The name of the parameter group to be associated with this cluster. Default: The default Amazon Redshift cluster parameter group. For information about the default parameter group, go to Working with Amazon Redshift Parameter Groups  Constraints:   Must be 1 to 255 alphanumeric characters or hyphens.   First character must be a letter.   Cannot end with a hyphen or contain two consecutive hyphens.  . Defaults to None.
        automated_snapshot_retention_period(int, optional): The number of days that automated snapshots are retained. If the value is 0, automated snapshots are disabled. Even if automated snapshots are disabled, you can still create manual snapshots when you want with CreateClusterSnapshot.  You can't disable automated snapshots for RA3 node types. Set the automated retention period from 1-35 days. Default: 1  Constraints: Must be a value from 0 to 35. Defaults to None.
        manual_snapshot_retention_period(int, optional): The default number of days to retain a manual snapshot. If the value is -1, the snapshot is retained indefinitely. This setting doesn't change the retention period of existing snapshots. The value must be either -1 or an integer between 1 and 3,653. Defaults to None.
        port(int, optional): The port number on which the cluster accepts incoming connections. The cluster is accessible only via the JDBC and ODBC connection strings. Part of the connection string requires the port on which the cluster will listen for incoming connections. Default: 5439  Valid Values: 1150-65535 . Defaults to None.
        cluster_version(str, optional): The version of the Amazon Redshift engine software that you want to deploy on the cluster. The version selected runs on all the nodes in the cluster. Constraints: Only version 1.0 is currently available. Example: 1.0 . Defaults to None.
        allow_version_upgrade(bool, optional): If true, major version upgrades can be applied during the maintenance window to the Amazon Redshift engine that is running on the cluster. When a new major version of the Amazon Redshift engine is released, you can request that the service automatically apply upgrades during the maintenance window to the Amazon Redshift engine that is running on your cluster. Default: true . Defaults to None.
        number_of_nodes(int, optional): The number of compute nodes in the cluster. This parameter is required when the ClusterType parameter is specified as multi-node.  For information about determining how many nodes you need, go to  Working with Clusters in the Amazon Redshift Cluster Management Guide.  If you don't specify this parameter, you get a single-node cluster. When requesting a multi-node cluster, you must specify the number of nodes that you want in the cluster. Default: 1  Constraints: Value must be at least 1 and no more than 100. Defaults to None.
        publicly_accessible(bool, optional): If true, the cluster can be accessed from a public network. . Defaults to None.
        encrypted(bool, optional): If true, the data in the cluster is encrypted at rest.  Default: false. Defaults to None.
        hsm_client_certificate_identifier(str, optional): Specifies the name of the HSM client certificate the Amazon Redshift cluster uses to retrieve the data encryption keys stored in an HSM. Defaults to None.
        hsm_configuration_identifier(str, optional): Specifies the name of the HSM configuration that contains the information the Amazon Redshift cluster can use to retrieve and store keys in an HSM. Defaults to None.
        elastic_ip(str, optional): The Elastic IP (EIP) address for the cluster. Constraints: The cluster must be provisioned in EC2-VPC and publicly-accessible through an Internet gateway. For more information about provisioning clusters in EC2-VPC, go to Supported Platforms to Launch Your Cluster in the Amazon Redshift Cluster Management Guide. Defaults to None.
        tags(List, optional): A list of tag instances. Defaults to None.
        kms_key_id(str, optional): The Key Management Service (KMS) key ID of the encryption key that you want to use to encrypt data in the cluster. Defaults to None.
        enhanced_vpc_routing(bool, optional): An option that specifies whether to create the cluster with enhanced VPC routing enabled. To create a cluster that uses enhanced VPC routing, the cluster must be in a VPC. For more information, see Enhanced VPC Routing in the Amazon Redshift Cluster Management Guide. If this option is true, enhanced VPC routing is enabled.  Default: false. Defaults to None.
        additional_info(str, optional): Reserved. Defaults to None.
        iam_roles(List, optional): A list of Identity and Access Management (IAM) roles that can be used by the cluster to access other Amazon Web Services services. You must supply the IAM roles in their Amazon Resource Name (ARN) format. You can supply up to 10 IAM roles in a single request. A cluster can have up to 10 IAM roles associated with it at any time. Defaults to None.
        maintenance_track_name(str, optional): An optional parameter for the name of the maintenance track for the cluster. If you don't provide a maintenance track name, the cluster is assigned to the current track. Defaults to None.
        snapshot_schedule_identifier(str, optional): A unique identifier for the snapshot schedule. Defaults to None.
        availability_zone_relocation(bool, optional): The option to enable relocation for an Amazon Redshift cluster between Availability Zones after the cluster is created. Defaults to None.
        aqua_configuration_status(str, optional): The value represents how the cluster is configured to use AQUA (Advanced Query Accelerator) when it is created. Possible values include the following.   enabled - Use AQUA if it is available for the current Amazon Web Services Region and Amazon Redshift node type.   disabled - Don't use AQUA.    auto - Amazon Redshift determines whether to use AQUA.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.cluster.init.create(
                ctx,
                cluster_identifier=value,
                node_type=value,
                master_username=value,
                master_user_password=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.cluster.init.create cluster_identifier=value, node_type=value, master_username=value, master_user_password=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="create_cluster",
        op_kwargs={
            "DBName": db_name,
            "ClusterIdentifier": cluster_identifier,
            "ClusterType": cluster_type,
            "NodeType": node_type,
            "MasterUsername": master_username,
            "MasterUserPassword": master_user_password,
            "ClusterSecurityGroups": cluster_security_groups,
            "VpcSecurityGroupIds": vpc_security_group_ids,
            "ClusterSubnetGroupName": cluster_subnet_group_name,
            "AvailabilityZone": availability_zone,
            "PreferredMaintenanceWindow": preferred_maintenance_window,
            "ClusterParameterGroupName": cluster_parameter_group_name,
            "AutomatedSnapshotRetentionPeriod": automated_snapshot_retention_period,
            "ManualSnapshotRetentionPeriod": manual_snapshot_retention_period,
            "Port": port,
            "ClusterVersion": cluster_version,
            "AllowVersionUpgrade": allow_version_upgrade,
            "NumberOfNodes": number_of_nodes,
            "PubliclyAccessible": publicly_accessible,
            "Encrypted": encrypted,
            "HsmClientCertificateIdentifier": hsm_client_certificate_identifier,
            "HsmConfigurationIdentifier": hsm_configuration_identifier,
            "ElasticIp": elastic_ip,
            "Tags": tags,
            "KmsKeyId": kms_key_id,
            "EnhancedVpcRouting": enhanced_vpc_routing,
            "AdditionalInfo": additional_info,
            "IamRoles": iam_roles,
            "MaintenanceTrackName": maintenance_track_name,
            "SnapshotScheduleIdentifier": snapshot_schedule_identifier,
            "AvailabilityZoneRelocation": availability_zone_relocation,
            "AquaConfigurationStatus": aqua_configuration_status,
        },
    )


async def delete(
    hub,
    ctx,
    cluster_identifier: str,
    skip_final_cluster_snapshot: bool = None,
    final_cluster_snapshot_identifier: str = None,
    final_cluster_snapshot_retention_period: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a previously provisioned cluster without its final snapshot being created. A successful response from the web service indicates that the request was received correctly. Use DescribeClusters to monitor the status of the deletion. The delete operation cannot be canceled or reverted once submitted. For more information about managing clusters, go to Amazon Redshift Clusters in the Amazon Redshift Cluster Management Guide. If you want to shut down the cluster and retain it for future use, set SkipFinalClusterSnapshot to false and specify a name for FinalClusterSnapshotIdentifier. You can later restore this snapshot to resume using the cluster. If a final cluster snapshot is requested, the status of the cluster will be "final-snapshot" while the snapshot is being taken, then it's "deleting" once Amazon Redshift begins deleting the cluster.   For more information about managing clusters, go to Amazon Redshift Clusters in the Amazon Redshift Cluster Management Guide.

    Args:
        cluster_identifier(str): The identifier of the cluster to be deleted. Constraints:   Must contain lowercase characters.   Must contain from 1 to 63 alphanumeric characters or hyphens.   First character must be a letter.   Cannot end with a hyphen or contain two consecutive hyphens.  .
        skip_final_cluster_snapshot(bool, optional): Determines whether a final snapshot of the cluster is created before Amazon Redshift deletes the cluster. If true, a final cluster snapshot is not created. If false, a final cluster snapshot is created before the cluster is deleted.   The FinalClusterSnapshotIdentifier parameter must be specified if SkipFinalClusterSnapshot is false.  Default: false . Defaults to None.
        final_cluster_snapshot_identifier(str, optional): The identifier of the final snapshot that is to be created immediately before deleting the cluster. If this parameter is provided, SkipFinalClusterSnapshot must be false.  Constraints:   Must be 1 to 255 alphanumeric characters.   First character must be a letter.   Cannot end with a hyphen or contain two consecutive hyphens.  . Defaults to None.
        final_cluster_snapshot_retention_period(int, optional): The number of days that a manual snapshot is retained. If the value is -1, the manual snapshot is retained indefinitely. The value must be either -1 or an integer between 1 and 3,653. The default value is -1. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.cluster.init.delete(ctx, cluster_identifier=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.cluster.init.delete cluster_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="delete_cluster",
        op_kwargs={
            "ClusterIdentifier": cluster_identifier,
            "SkipFinalClusterSnapshot": skip_final_cluster_snapshot,
            "FinalClusterSnapshotIdentifier": final_cluster_snapshot_identifier,
            "FinalClusterSnapshotRetentionPeriod": final_cluster_snapshot_retention_period,
        },
    )


async def describe_all(
    hub,
    ctx,
    cluster_identifier: str = None,
    max_records: int = None,
    marker: str = None,
    tag_keys: List = None,
    tag_values: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns properties of provisioned clusters including general cluster properties, cluster database properties, maintenance and backup properties, and security and access properties. This operation supports pagination. For more information about managing clusters, go to Amazon Redshift Clusters in the Amazon Redshift Cluster Management Guide. If you specify both tag keys and tag values in the same request, Amazon Redshift returns all clusters that match any combination of the specified keys and values. For example, if you have owner and environment for tag keys, and admin and test for tag values, all clusters that have any combination of those values are returned. If both tag keys and values are omitted from the request, clusters are returned regardless of whether they have tag keys or values associated with them.

    Args:
        cluster_identifier(str, optional): The unique identifier of a cluster whose properties you are requesting. This parameter is case sensitive. The default is that all clusters defined for an account are returned. Defaults to None.
        max_records(int, optional): The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in a marker field of the response. You can retrieve the next set of records by retrying the command with the returned marker value.  Default: 100  Constraints: minimum 20, maximum 100. Defaults to None.
        marker(str, optional): An optional parameter that specifies the starting point to return a set of response records. When the results of a DescribeClusters request exceed the value specified in MaxRecords, Amazon Web Services returns a value in the Marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the Marker parameter and retrying the request.  Constraints: You can specify either the ClusterIdentifier parameter or the Marker parameter, but not both. . Defaults to None.
        tag_keys(List, optional): A tag key or keys for which you want to return all matching clusters that are associated with the specified key or keys. For example, suppose that you have clusters that are tagged with keys called owner and environment. If you specify both of these tag keys in the request, Amazon Redshift returns a response with the clusters that have either or both of these tag keys associated with them. Defaults to None.
        tag_values(List, optional): A tag value or values for which you want to return all matching clusters that are associated with the specified tag value or values. For example, suppose that you have clusters that are tagged with values called admin and test. If you specify both of these tag values in the request, Amazon Redshift returns a response with the clusters that have either or both of these tag values associated with them. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.cluster.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.cluster.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="describe_clusters",
        op_kwargs={
            "ClusterIdentifier": cluster_identifier,
            "MaxRecords": max_records,
            "Marker": marker,
            "TagKeys": tag_keys,
            "TagValues": tag_values,
        },
    )


async def modify(
    hub,
    ctx,
    cluster_identifier: str,
    cluster_type: str = None,
    node_type: str = None,
    number_of_nodes: int = None,
    cluster_security_groups: List = None,
    vpc_security_group_ids: List = None,
    master_user_password: str = None,
    cluster_parameter_group_name: str = None,
    automated_snapshot_retention_period: int = None,
    manual_snapshot_retention_period: int = None,
    preferred_maintenance_window: str = None,
    cluster_version: str = None,
    allow_version_upgrade: bool = None,
    hsm_client_certificate_identifier: str = None,
    hsm_configuration_identifier: str = None,
    new_cluster_identifier: str = None,
    publicly_accessible: bool = None,
    elastic_ip: str = None,
    enhanced_vpc_routing: bool = None,
    maintenance_track_name: str = None,
    encrypted: bool = None,
    kms_key_id: str = None,
    availability_zone_relocation: bool = None,
    availability_zone: str = None,
    port: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the settings for a cluster. You can also change node type and the number of nodes to scale up or down the cluster. When resizing a cluster, you must specify both the number of nodes and the node type even if one of the parameters does not change. You can add another security or parameter group, or change the admin user password. Resetting a cluster password or modifying the security groups associated with a cluster do not need a reboot. However, modifying a parameter group requires a reboot for parameters to take effect. For more information about managing clusters, go to Amazon Redshift Clusters in the Amazon Redshift Cluster Management Guide.

    Args:
        cluster_identifier(str): The unique identifier of the cluster to be modified. Example: examplecluster .
        cluster_type(str, optional): The new cluster type. When you submit your cluster resize request, your existing cluster goes into a read-only mode. After Amazon Redshift provisions a new cluster based on your resize requirements, there will be outage for a period while the old cluster is deleted and your connection is switched to the new cluster. You can use DescribeResize to track the progress of the resize request.  Valid Values:  multi-node | single-node  . Defaults to None.
        node_type(str, optional): The new node type of the cluster. If you specify a new node type, you must also specify the number of nodes parameter.  For more information about resizing clusters, go to Resizing Clusters in Amazon Redshift in the Amazon Redshift Cluster Management Guide. Valid Values: ds2.xlarge | ds2.8xlarge | dc1.large | dc1.8xlarge | dc2.large | dc2.8xlarge | ra3.xlplus | ra3.4xlarge | ra3.16xlarge . Defaults to None.
        number_of_nodes(int, optional): The new number of nodes of the cluster. If you specify a new number of nodes, you must also specify the node type parameter.  For more information about resizing clusters, go to Resizing Clusters in Amazon Redshift in the Amazon Redshift Cluster Management Guide. Valid Values: Integer greater than 0. Defaults to None.
        cluster_security_groups(List, optional): A list of cluster security groups to be authorized on this cluster. This change is asynchronously applied as soon as possible. Security groups currently associated with the cluster, and not in the list of groups to apply, will be revoked from the cluster. Constraints:   Must be 1 to 255 alphanumeric characters or hyphens   First character must be a letter   Cannot end with a hyphen or contain two consecutive hyphens  . Defaults to None.
        vpc_security_group_ids(List, optional): A list of virtual private cloud (VPC) security groups to be associated with the cluster. This change is asynchronously applied as soon as possible. Defaults to None.
        master_user_password(str, optional): The new password for the cluster admin user. This change is asynchronously applied as soon as possible. Between the time of the request and the completion of the request, the MasterUserPassword element exists in the PendingModifiedValues element of the operation response.   Operations never return the password, so this operation provides a way to regain access to the admin user account for a cluster if the password is lost.  Default: Uses existing setting. Constraints:   Must be between 8 and 64 characters in length.   Must contain at least one uppercase letter.   Must contain at least one lowercase letter.   Must contain one number.   Can be any printable ASCII character (ASCII code 33 to 126) except ' (single quote), " (double quote), \, /, @, or space.  . Defaults to None.
        cluster_parameter_group_name(str, optional): The name of the cluster parameter group to apply to this cluster. This change is applied only after the cluster is rebooted. To reboot a cluster use RebootCluster.  Default: Uses existing setting. Constraints: The cluster parameter group must be in the same parameter group family that matches the cluster version. Defaults to None.
        automated_snapshot_retention_period(int, optional): The number of days that automated snapshots are retained. If the value is 0, automated snapshots are disabled. Even if automated snapshots are disabled, you can still create manual snapshots when you want with CreateClusterSnapshot.  If you decrease the automated snapshot retention period from its current value, existing automated snapshots that fall outside of the new retention period will be immediately deleted. You can't disable automated snapshots for RA3 node types. Set the automated retention period from 1-35 days. Default: Uses existing setting. Constraints: Must be a value from 0 to 35. Defaults to None.
        manual_snapshot_retention_period(int, optional): The default for number of days that a newly created manual snapshot is retained. If the value is -1, the manual snapshot is retained indefinitely. This value doesn't retroactively change the retention periods of existing manual snapshots. The value must be either -1 or an integer between 1 and 3,653. The default value is -1. Defaults to None.
        preferred_maintenance_window(str, optional): The weekly time range (in UTC) during which system maintenance can occur, if necessary. If system maintenance is necessary during the window, it may result in an outage. This maintenance window change is made immediately. If the new maintenance window indicates the current time, there must be at least 120 minutes between the current time and end of the window in order to ensure that pending changes are applied. Default: Uses existing setting. Format: ddd:hh24:mi-ddd:hh24:mi, for example wed:07:30-wed:08:00. Valid Days: Mon | Tue | Wed | Thu | Fri | Sat | Sun Constraints: Must be at least 30 minutes. Defaults to None.
        cluster_version(str, optional): The new version number of the Amazon Redshift engine to upgrade to. For major version upgrades, if a non-default cluster parameter group is currently in use, a new cluster parameter group in the cluster parameter group family for the new version must be specified. The new cluster parameter group can be the default for that cluster parameter group family. For more information about parameters and parameter groups, go to Amazon Redshift Parameter Groups in the Amazon Redshift Cluster Management Guide. Example: 1.0 . Defaults to None.
        allow_version_upgrade(bool, optional): If true, major version upgrades will be applied automatically to the cluster during the maintenance window.  Default: false . Defaults to None.
        hsm_client_certificate_identifier(str, optional): Specifies the name of the HSM client certificate the Amazon Redshift cluster uses to retrieve the data encryption keys stored in an HSM. Defaults to None.
        hsm_configuration_identifier(str, optional): Specifies the name of the HSM configuration that contains the information the Amazon Redshift cluster can use to retrieve and store keys in an HSM. Defaults to None.
        new_cluster_identifier(str, optional): The new identifier for the cluster. Constraints:   Must contain from 1 to 63 alphanumeric characters or hyphens.   Alphabetic characters must be lowercase.   First character must be a letter.   Cannot end with a hyphen or contain two consecutive hyphens.   Must be unique for all clusters within an Amazon Web Services account.   Example: examplecluster . Defaults to None.
        publicly_accessible(bool, optional): If true, the cluster can be accessed from a public network. Only clusters in VPCs can be set to be publicly available. Defaults to None.
        elastic_ip(str, optional): The Elastic IP (EIP) address for the cluster. Constraints: The cluster must be provisioned in EC2-VPC and publicly-accessible through an Internet gateway. For more information about provisioning clusters in EC2-VPC, go to Supported Platforms to Launch Your Cluster in the Amazon Redshift Cluster Management Guide. Defaults to None.
        enhanced_vpc_routing(bool, optional): An option that specifies whether to create the cluster with enhanced VPC routing enabled. To create a cluster that uses enhanced VPC routing, the cluster must be in a VPC. For more information, see Enhanced VPC Routing in the Amazon Redshift Cluster Management Guide. If this option is true, enhanced VPC routing is enabled.  Default: false. Defaults to None.
        maintenance_track_name(str, optional): The name for the maintenance track that you want to assign for the cluster. This name change is asynchronous. The new track name stays in the PendingModifiedValues for the cluster until the next maintenance window. When the maintenance track changes, the cluster is switched to the latest cluster release available for the maintenance track. At this point, the maintenance track name is applied. Defaults to None.
        encrypted(bool, optional): Indicates whether the cluster is encrypted. If the value is encrypted (true) and you provide a value for the KmsKeyId parameter, we encrypt the cluster with the provided KmsKeyId. If you don't provide a KmsKeyId, we encrypt with the default key.  If the value is not encrypted (false), then the cluster is decrypted. . Defaults to None.
        kms_key_id(str, optional): The Key Management Service (KMS) key ID of the encryption key that you want to use to encrypt data in the cluster. Defaults to None.
        availability_zone_relocation(bool, optional): The option to enable relocation for an Amazon Redshift cluster between Availability Zones after the cluster modification is complete. Defaults to None.
        availability_zone(str, optional): The option to initiate relocation for an Amazon Redshift cluster to the target Availability Zone. Defaults to None.
        port(int, optional): The option to change the port of an Amazon Redshift cluster. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.cluster.init.modify(ctx, cluster_identifier=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.cluster.init.modify cluster_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="modify_cluster",
        op_kwargs={
            "ClusterIdentifier": cluster_identifier,
            "ClusterType": cluster_type,
            "NodeType": node_type,
            "NumberOfNodes": number_of_nodes,
            "ClusterSecurityGroups": cluster_security_groups,
            "VpcSecurityGroupIds": vpc_security_group_ids,
            "MasterUserPassword": master_user_password,
            "ClusterParameterGroupName": cluster_parameter_group_name,
            "AutomatedSnapshotRetentionPeriod": automated_snapshot_retention_period,
            "ManualSnapshotRetentionPeriod": manual_snapshot_retention_period,
            "PreferredMaintenanceWindow": preferred_maintenance_window,
            "ClusterVersion": cluster_version,
            "AllowVersionUpgrade": allow_version_upgrade,
            "HsmClientCertificateIdentifier": hsm_client_certificate_identifier,
            "HsmConfigurationIdentifier": hsm_configuration_identifier,
            "NewClusterIdentifier": new_cluster_identifier,
            "PubliclyAccessible": publicly_accessible,
            "ElasticIp": elastic_ip,
            "EnhancedVpcRouting": enhanced_vpc_routing,
            "MaintenanceTrackName": maintenance_track_name,
            "Encrypted": encrypted,
            "KmsKeyId": kms_key_id,
            "AvailabilityZoneRelocation": availability_zone_relocation,
            "AvailabilityZone": availability_zone,
            "Port": port,
        },
    )


async def pause(hub, ctx, cluster_identifier: str) -> Dict:
    r"""
    **Autogenerated function**

    Pauses a cluster.

    Args:
        cluster_identifier(str): The identifier of the cluster to be paused.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.cluster.init.pause(ctx, cluster_identifier=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.cluster.init.pause cluster_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="pause_cluster",
        op_kwargs={"ClusterIdentifier": cluster_identifier},
    )


async def reboot(hub, ctx, cluster_identifier: str) -> Dict:
    r"""
    **Autogenerated function**

    Reboots a cluster. This action is taken as soon as possible. It results in a momentary outage to the cluster, during which the cluster status is set to rebooting. A cluster event is created when the reboot is completed. Any pending cluster modifications (see ModifyCluster) are applied at this reboot. For more information about managing clusters, go to Amazon Redshift Clusters in the Amazon Redshift Cluster Management Guide.

    Args:
        cluster_identifier(str): The cluster identifier.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.cluster.init.reboot(ctx, cluster_identifier=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.cluster.init.reboot cluster_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="reboot_cluster",
        op_kwargs={"ClusterIdentifier": cluster_identifier},
    )


async def resize(
    hub,
    ctx,
    cluster_identifier: str,
    cluster_type: str = None,
    node_type: str = None,
    number_of_nodes: int = None,
    classic: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Changes the size of the cluster. You can change the cluster's type, or change the number or type of nodes. The default behavior is to use the elastic resize method. With an elastic resize, your cluster is available for read and write operations more quickly than with the classic resize method.  Elastic resize operations have the following restrictions:   You can only resize clusters of the following types:   dc1.large (if your cluster is in a VPC)   dc1.8xlarge (if your cluster is in a VPC)   dc2.large   dc2.8xlarge   ds2.xlarge   ds2.8xlarge   ra3.xlplus   ra3.4xlarge   ra3.16xlarge     The type of nodes that you add must match the node type for the cluster.

    Args:
        cluster_identifier(str): The unique identifier for the cluster to resize.
        cluster_type(str, optional): The new cluster type for the specified cluster. Defaults to None.
        node_type(str, optional): The new node type for the nodes you are adding. If not specified, the cluster's current node type is used. Defaults to None.
        number_of_nodes(int, optional): The new number of nodes for the cluster. If not specified, the cluster's current number of nodes is used. Defaults to None.
        classic(bool, optional): A boolean value indicating whether the resize operation is using the classic resize process. If you don't provide this parameter or set the value to false, the resize type is elastic. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.cluster.init.resize(ctx, cluster_identifier=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.cluster.init.resize cluster_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="resize_cluster",
        op_kwargs={
            "ClusterIdentifier": cluster_identifier,
            "ClusterType": cluster_type,
            "NodeType": node_type,
            "NumberOfNodes": number_of_nodes,
            "Classic": classic,
        },
    )


async def resume(hub, ctx, cluster_identifier: str) -> Dict:
    r"""
    **Autogenerated function**

    Resumes a paused cluster.

    Args:
        cluster_identifier(str): The identifier of the cluster to be resumed.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.cluster.init.resume(ctx, cluster_identifier=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.cluster.init.resume cluster_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="resume_cluster",
        op_kwargs={"ClusterIdentifier": cluster_identifier},
    )
